diff --git a/src/backend/catalog/system_views.sql b/src/backend/catalog/system_views.sql
index 8630542..4e61f54 100644
--- a/src/backend/catalog/system_views.sql
+++ b/src/backend/catalog/system_views.sql
@@ -162,7 +162,7 @@ CREATE VIEW pg_indexes AS
          JOIN pg_class I ON (I.oid = X.indexrelid)
          LEFT JOIN pg_namespace N ON (N.oid = C.relnamespace)
          LEFT JOIN pg_tablespace T ON (T.oid = I.reltablespace)
-    WHERE C.relkind IN ('r', 'm') AND I.relkind = 'i';
+    WHERE C.relkind IN ('r', 'm','p') AND I.relkind IN ('i','I');
 
 CREATE OR REPLACE VIEW pg_sequences AS
     SELECT
diff --git a/src/test/regress/expected/indexing.out b/src/test/regress/expected/indexing.out
index 3e61f50..12cd1c8 100644
--- a/src/test/regress/expected/indexing.out
+++ b/src/test/regress/expected/indexing.out
@@ -10,6 +10,13 @@ select relhassubclass from pg_class where relname = 'idxpart_idx';
  f
 (1 row)
 
+-- Check if that index is present in pg_indexes view:
+select * from pg_indexes where indexname ilike 'idxpart_idx%' order by 3;
+ schemaname | tablename |  indexname  | tablespace |                            indexdef                             
+------------+-----------+-------------+------------+-----------------------------------------------------------------
+ public     | idxpart   | idxpart_idx |            | CREATE INDEX idxpart_idx ON ONLY public.idxpart USING btree (a)
+(1 row)
+
 drop index idxpart_idx;
 create table idxpart1 partition of idxpart for values from (0) to (10);
 create table idxpart2 partition of idxpart for values from (10) to (100)
diff --git a/src/test/regress/expected/rules.out b/src/test/regress/expected/rules.out
index b68b8d2..e384cd2 100644
--- a/src/test/regress/expected/rules.out
+++ b/src/test/regress/expected/rules.out
@@ -1358,7 +1358,7 @@ pg_indexes| SELECT n.nspname AS schemaname,
      JOIN pg_class i ON ((i.oid = x.indexrelid)))
      LEFT JOIN pg_namespace n ON ((n.oid = c.relnamespace)))
      LEFT JOIN pg_tablespace t ON ((t.oid = i.reltablespace)))
-  WHERE ((c.relkind = ANY (ARRAY['r'::"char", 'm'::"char"])) AND (i.relkind = 'i'::"char"));
+  WHERE ((c.relkind = ANY (ARRAY['r'::"char", 'm'::"char", 'p'::"char"])) AND (i.relkind = ANY (ARRAY['i'::"char", 'I'::"char"])));
 pg_locks| SELECT l.locktype,
     l.database,
     l.relation,
diff --git a/src/test/regress/sql/indexing.sql b/src/test/regress/sql/indexing.sql
index 400b7eb..5093256 100644
--- a/src/test/regress/sql/indexing.sql
+++ b/src/test/regress/sql/indexing.sql
@@ -6,6 +6,8 @@ create table idxpart (a int, b int, c text) partition by range (a);
 -- It will be set after the first partition is created.
 create index idxpart_idx on idxpart (a);
 select relhassubclass from pg_class where relname = 'idxpart_idx';
+-- Check if that index is present in pg_indexes view:
+select * from pg_indexes where indexname ilike 'idxpart_idx%' order by 3;
 drop index idxpart_idx;
 
 create table idxpart1 partition of idxpart for values from (0) to (10);
